#
# spec file for package hlint
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hlint
Name:           %{pkg_name}
Version:        3.2.7
Release:        bp155.3.14
Summary:        Source code suggestions
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{name}-%{version}/revision/2.cabal#/%{name}.cabal
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cmdargs-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cpphs-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-extra-devel
BuildRequires:  ghc-file-embed-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepattern-devel
BuildRequires:  ghc-ghc-boot-devel
BuildRequires:  ghc-ghc-boot-th-devel
BuildRequires:  ghc-ghc-devel
BuildRequires:  ghc-ghc-lib-parser-ex-devel
BuildRequires:  ghc-hscolour-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-refact-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-uniplate-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-yaml-devel
ExcludeArch:    %{ix86}

%description
HLint gives suggestions on how to improve your source code.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%autosetup
cp -p %{SOURCE1} %{name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}
install -D --mode=444 data/hlint.1 %{buildroot}%{_mandir}/man1/hlint.1

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc CHANGES.txt README.md
%{_bindir}/%{name}
%dir %{_datadir}/%{name}-%{version}
%{_datadir}/%{name}-%{version}/HLint_QuickCheck.hs
%{_datadir}/%{name}-%{version}/HLint_TypeCheck.hs
%{_datadir}/%{name}-%{version}/Test.hs
%{_datadir}/%{name}-%{version}/default.yaml
%{_datadir}/%{name}-%{version}/hlint.1
%{_datadir}/%{name}-%{version}/hlint.ghci
%{_datadir}/%{name}-%{version}/hlint.yaml
%{_datadir}/%{name}-%{version}/hs-lint.el
%{_datadir}/%{name}-%{version}/report_template.html

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%{_mandir}/man1/hlint.1%{?ext_man}
%doc CHANGES.txt README.md

%changelog
* Mon Oct 11 2021 Peter Simons <psimons@suse.com>
- Update hlint to version 3.2.7 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Sep  2 2021 psimons@suse.com
- Update hlint to version 3.2.7 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jan 18 2021 psimons@suse.com
- Update hlint to version 3.2.7.
  3.2.7, released 2021-01-16
    [#1202], add missing parentheses for Avoid Lambda
    [#1201], allow matching through the & operator (similar to $)
    [#1196], fix removed parens with operator sections in some cases
* Mon Jan  4 2021 psimons@suse.com
- Update hlint to version 3.2.6.
  3.2.6, released 2020-12-30
    Fixes to the release generation script
* Wed Dec 30 2020 psimons@suse.com
- Update hlint to version 3.2.5.
  3.2.5, released 2020-12-30
    Fixes to the release generation script
  3.2.4, released 2020-12-30
    [#1193], add warnings for redundant flip
    [#1183], allow matches where users specify unnecessary brackets
    [#1177], remove suggestions for fromMaybe False/fromMaybe True
    [#1176], suggest use of unzip
    [#1159], spot redundant brackets due to fixities, default ignored
    [#1172], suggest reusing fromLeft/fromRight
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Nov 23 2020 psimons@suse.com
- Update hlint to version 3.2.3.
  3.2.3, released 2020-11-23
    [#1160], never consult the .hscolour file for color preferences
    [#1171], do not refactor redundant lambda with case
    [#1169], default to -A32 (doubles speed for 4 CPU)
    [#1169], make -j actually use parallelism
    [#1167], enable refactoring for "Use lambda"
* Sun Nov 15 2020 psimons@suse.com
- Update hlint to version 3.2.2.
  3.2.2, released 2020-11-15
    [#1166], detect more unboxed data to avoid suggesting newtype
    [#1153], fix incorrect redundant bracket with @($foo)
    [#1163], do not suggest "Use lambda" when there are guards
    [#1160], add showIdeaANSI to show Idea values with escape codes
* Fri Oct 16 2020 psimons@suse.com
- Update hlint to version 3.2.1.
  3.2.1, released 2020-10-15
    [#1150], remove the Duplicate hint (was slow)
    [#1149], allow within to use module wildcards, e.g. **.Foo
    [#1141], make redundant return highlight just the return
    [#1142], suggest newtype instead of data for data family instances
    [#1138], show allowed fields in YAML error message
    [#1131], fix potential variable capture in zipWith/repeat hint
    [#1129], add hints to use const and \_ x -> x where appropriate
* Tue Sep 15 2020 psimons@suse.com
- Update hlint to version 3.2.
  3.2, released 2020-09-14
    [#75], make Windows 10 use color terminals
    Make sure the extension removed matches what you called it
  * #1124, make test into a flag rather than a mode, use --test
    [#1073], add LHS/RHS hints to the summary
  * Remove test --proof, --quickcheck and --typecheck, --tempdir
  * #1123, delete grep mode
    [#1122], show the --refactor command line with --loud
    [#1120], enable refactoring for use section
    [#1114], enable refactoring for redundant as-pattern
    [#1116], enable refactoring for redundant section
    [#1115], more TVar/TMVar hints
    [#1113], suggest x >>= pure . f becomes x <&> f
    [#1111], add hint for \x y -> (x,y) to (,), and for (,,)
    [#1108], enable refactoring for redundant variable capture
    [#1105], enable refactoring for more redundant return hints
    [#1103], enable refactoring for Redundant void
    [#1083], add hints for mempty as a function
    [#1097], enable refactoring for more avoid lambda hints
    [#1094], error on `-XFoo` if `Foo` is not a known extension
    [#1090], improve --verbose to print more information
    [#1085], support eta-reduce refactoring
    [#780], ignore dist and dist-newstyle directories
    [#1076], fix -XNoCpp and CPP around LANGUAGE extensions
    [#1077], warn on unused StandaloneKindSignatures
    [#1070], warn on unused ImportQualifiedPost
    [#1067], require apply-refact 0.8.1.0 (fixes lots of bugs)
    [#1064], don't remove OverloadedLists if there is a []
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 6GB min disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Thu Jun 25 2020 psimons@suse.com
- Update hlint to version 3.1.6.
  3.1.6, released 2020-06-24
    [#1062], make sure matching inserts brackets if required
    [#1058], weaken the self-definition check to match more things
    [#1060], suggest [] ++ x and [] ++ x to x
* Tue Jun 23 2020 psimons@suse.com
- Add hlint at version 3.1.5.
